@@ -5,10 +5,11 @@
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
-//
-// UNSUPPORTED: libcpp-has-no-threads
+
 // UNSUPPORTED: c++03
 
+// XFAIL: !has-64-bit-atomics
+
 // <atomic>
 
 // constexpr atomic<T>::atomic(T value)
@@ -42,10 +43,6 @@ struct TestFunc {
       constexpr Atomic a{t};
       assert(a == t);
     }
-    {
-      constexpr Atomic a = ATOMIC_VAR_INIT(t);
-      assert(a == t);
-    }
   }
 };
 
