@@ -1,12 +1,13 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
+// ADDITIONAL_COMPILE_FLAGS: -D_LIBCPP_DISABLE_DEPRECATION_WARNINGS -D_LIBCPP_ENABLE_CXX26_REMOVED_STRSTREAM
+
 // <strstream>
 
 // class istrstream
@@ -17,7 +18,9 @@
 #include <cassert>
 #include <string>
 
-int main()
+#include "test_macros.h"
+
+int main(int, char**)
 {
     {
         const char buf[] = "123 4.5 dog";
@@ -41,4 +44,6 @@ int main()
         assert(buf[5] == '.');
         assert(buf[6] == '5');
     }
+
+  return 0;
 }
