@@ -36,10 +36,8 @@ int main(int, char**)
 #if TEST_STD_VER > 17 && defined(__cpp_char8_t)
     test<char8_t>(0);
 #endif
-#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
     test<char16_t>(0);
     test<char32_t>(0);
-#endif // _LIBCPP_HAS_NO_UNICODE_CHARS
     test<short>(0);
     test<unsigned short>(0);
     test<int>(0);
@@ -48,7 +46,7 @@ int main(int, char**)
     test<unsigned long>(0);
     test<long long>(0);
     test<unsigned long long>(0);
-#ifndef _LIBCPP_HAS_NO_INT128
+#ifndef TEST_HAS_NO_INT128
     test<__int128_t>(0);
     test<__uint128_t>(0);
 #endif
