@@ -17,75 +17,61 @@
 
 #include "test_macros.h"
 #include "min_allocator.h"
+#include "asan_testing.h"
 
 template <class S>
-TEST_CONSTEXPR_CXX20 void
-test(S s, typename S::size_type pos, typename S::size_type n, S expected)
-{
-    const typename S::size_type old_size = s.size();
-    S s0 = s;
-    if (pos <= old_size)
-    {
-        s.erase(pos, n);
-        LIBCPP_ASSERT(s.__invariants());
-        assert(s[s.size()] == typename S::value_type());
-        assert(s == expected);
-    }
-#ifndef TEST_HAS_NO_EXCEPTIONS
-    else if (!TEST_IS_CONSTANT_EVALUATED)
-    {
-        try
-        {
-            s.erase(pos, n);
-            assert(false);
-        }
-        catch (std::out_of_range&)
-        {
-            assert(pos > old_size);
-            assert(s == s0);
-        }
-    }
-#endif
-}
-
-template <class S>
-TEST_CONSTEXPR_CXX20 void
-test(S s, typename S::size_type pos, S expected)
-{
-    const typename S::size_type old_size = s.size();
-    S s0 = s;
-    if (pos <= old_size)
-    {
-        s.erase(pos);
-        LIBCPP_ASSERT(s.__invariants());
-        assert(s[s.size()] == typename S::value_type());
-        assert(s == expected);
-    }
-#ifndef TEST_HAS_NO_EXCEPTIONS
-    else if (!TEST_IS_CONSTANT_EVALUATED)
-    {
-        try
-        {
-            s.erase(pos);
-            assert(false);
-        }
-        catch (std::out_of_range&)
-        {
-            assert(pos > old_size);
-            assert(s == s0);
-        }
-    }
-#endif
-}
-
-template <class S>
-TEST_CONSTEXPR_CXX20 void
-test(S s, S expected)
-{
-    s.erase();
+TEST_CONSTEXPR_CXX20 void test(S s, typename S::size_type pos, typename S::size_type n, S expected) {
+  const typename S::size_type old_size = s.size();
+  S s0                                 = s;
+  if (pos <= old_size) {
+    s.erase(pos, n);
     LIBCPP_ASSERT(s.__invariants());
     assert(s[s.size()] == typename S::value_type());
     assert(s == expected);
+    LIBCPP_ASSERT(is_string_asan_correct(s));
+  }
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  else if (!TEST_IS_CONSTANT_EVALUATED) {
+    try {
+      s.erase(pos, n);
+      assert(false);
+    } catch (std::out_of_range&) {
+      assert(pos > old_size);
+      assert(s == s0);
+    }
+  }
+#endif
+}
+
+template <class S>
+TEST_CONSTEXPR_CXX20 void test(S s, typename S::size_type pos, S expected) {
+  const typename S::size_type old_size = s.size();
+  S s0                                 = s;
+  if (pos <= old_size) {
+    s.erase(pos);
+    LIBCPP_ASSERT(s.__invariants());
+    assert(s[s.size()] == typename S::value_type());
+    assert(s == expected);
+  }
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  else if (!TEST_IS_CONSTANT_EVALUATED) {
+    try {
+      s.erase(pos);
+      assert(false);
+    } catch (std::out_of_range&) {
+      assert(pos > old_size);
+      assert(s == s0);
+    }
+  }
+#endif
+}
+
+template <class S>
+TEST_CONSTEXPR_CXX20 void test(S s, S expected) {
+  s.erase();
+  LIBCPP_ASSERT(s.__invariants());
+  assert(s[s.size()] == typename S::value_type());
+  assert(s == expected);
 }
 
 template <class S>
@@ -196,13 +182,13 @@ TEST_CONSTEXPR_CXX20 bool test() {
   test_string<std::string>();
 #if TEST_STD_VER >= 11
   test_string<std::basic_string<char, std::char_traits<char>, min_allocator<char>>>();
+  test_string<std::basic_string<char, std::char_traits<char>, safe_allocator<char>>>();
 #endif
 
   return true;
 }
 
-int main(int, char**)
-{
+int main(int, char**) {
   test();
 #if TEST_STD_VER > 17
   static_assert(test());
