@@ -17,10 +17,9 @@
 
 #include "test_macros.h"
 
-int main(int, char**)
-{
-    assert(std::char_traits<char>::eq('a', 'a'));
-    assert(!std::char_traits<char>::eq('a', 'A'));
+int main(int, char**) {
+  assert(std::char_traits<char>::eq('a', 'a'));
+  assert(!std::char_traits<char>::eq('a', 'A'));
 
   return 0;
 }
